@@ -2,8 +2,8 @@
 
 package Perinci::CmdLine::Classic::Role::Help;
 
-our $DATE = '2021-05-07'; # DATE
-our $VERSION = '1.814'; # VERSION
+our $DATE = '2021-07-11'; # DATE
+our $VERSION = '1.815'; # VERSION
 
 # split here just so it's more organized
 
@@ -517,7 +517,7 @@ Perinci::CmdLine::Classic::Role::Help - Help-related routines
 
 =head1 VERSION
 
-This document describes version 1.814 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2021-05-07.
+This document describes version 1.815 of Perinci::CmdLine::Classic::Role::Help (from Perl distribution Perinci-CmdLine-Classic), released on 2021-07-11.
 
 =for Pod::Coverage ^(.+)$
 
@@ -542,7 +542,7 @@ Source repository is at L<https://github.com/perlancar/perl-Perinci-CmdLine-Clas
 
 =head1 BUGS
 
-Please report any bugs or feature requests on the bugtracker website L<https://github.com/perlancar/perl-Perinci-CmdLine-Classic/issues>
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Perinci-CmdLine-Classic>
 
 When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
